@@ -6,10 +6,24 @@ public class CmdResponse {
 	private String error;
 	private String output;
 	private Integer status;
+	private String version;
+	private String trace;
  
+	public String getTrace() {
+		return trace;
+	}
+	public void setTrace(String trace) {
+		this.trace = trace;
+	}
 	public CmdResponse() {
 		super();
 	}
+	public String getVersion() {
+		return version;
+	}
+	public void setVersion(String version) {
+		this.version = version;
+	}
 	public String getMessage() {
 		return message;
 	}
