@@ -392,7 +392,7 @@ public static void  writeBioPax3ToFile(String outFilePath, Model  modelCurrent )
 	        
  
 	 		 RawPatternSearchResult rp;
-		try {
+		//try {
 			
 			LogUtils.info("*************runDoSpaim::3********************");
 			SpaimGraphGenerator sgg = new SpaimGraphGenerator(
@@ -450,10 +450,11 @@ public static void  writeBioPax3ToFile(String outFilePath, Model  modelCurrent )
 				LogUtils.info("*************runDoSpaim::4.0.2********************");
 				LogUtils.info("************no graph*********");
 			}
+		/*
 		} catch (Exception e) {
 			LogUtils.info("*************runDoSpaim::error:"+e.getMessage()+"********************");
 			e.printStackTrace();
-		}
+		}*/
 		
 		LogUtils.info("*************runDoSpaim::end********************");
 	}
