@@ -3,6 +3,7 @@ import java.io.File;
 import java.io.IOException;
 
 import org.apache.commons.cli.*;
+import org.apache.commons.lang3.exception.ExceptionUtils;
 
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
@@ -16,18 +17,19 @@ public class Pax2GraphML {
 	private static final String DEFAULT_GRAPHML_TEMPLATE = "graphml.vm";
 	private static final String DEFAULT_BLACKLIST = "blacklist.txt";
     private static final String SEP = "###";
-
+    private static final String VERSION = "1.1.3";
 	
 	public static void main(String[] args) throws Exception {
 
+		CmdResponse cs = new CmdResponse();
 
+		cs.setVersion(VERSION);
 		 
 		  LogUtils.STDOUT=false;
 		  
 		final GsonBuilder builder = new GsonBuilder();
 	    final Gson gson = builder.create();
 
-		CmdResponse cs = new CmdResponse();
         Options options = new Options();
 
         Option input = new Option("i", "input", true, "biopax input file path");
@@ -61,10 +63,15 @@ public class Pax2GraphML {
               cmd = parser.parse(options, args);
         } catch (ParseException e) {
         
-               cs.setError(e.getMessage());
+               
+               String msg="parsing option exception:"+e.getClass().getName()+","+e.getMessage();
+       	       cs.setError(msg);
                cs.setStatus(1);
+               String trace = ExceptionUtils.getStackTrace(e);
+               cs.setTrace(trace);
                displayResponse(gson, cs);
                System.exit(1);
+               
         }
 
         String inputBiopaxFile = cmd.getOptionValue("input");
@@ -138,8 +145,11 @@ public class Pax2GraphML {
         cs.setOutput(graphmlOutputFilePath);
         displayResponse(gson, cs);
   }catch(Exception ex) {
-	    cs.setError(ex.getMessage());
+	    String msg="spaim exception:"+ex.getClass().getName()+","+ex.getMessage();
+	    cs.setError(msg);
         cs.setStatus(1);
+        String trace = ExceptionUtils.getStackTrace(ex);
+        cs.setTrace(trace);
         displayResponse(gson, cs);
         System.exit(1);
   }
