@@ -12,10 +12,11 @@ public static void main(String[] args) throws Exception {
      String d="/home/fmoreews/Documents/keyreg/publi/revision2/";
 	 
      //String  biopax_file=d+"subgraph.owl";
-	 
-     String  biopax_file=d+"G6P.owl";
+     String  biopax_file=d+"PathwayCommons12.ctd.BIOPAX.owl";
+   //  String  biopax_file=d+"G6P.owl";
    //  String  biopax_file=d+"PathwayCommons12.pid.BIOPAX.owl";
-	 String graphml_file=d+"subgraph_OUT.graphml";
+	// String graphml_file=d+"subgraph_OUT.graphml";
+     String graphml_file=d+"ctd.graphml";
 	// String  template=d+"graphml.vm";
 	 String  template=d+"graphml_l.vm";
 	 String  blackListOpt="";
