@@ -152,25 +152,7 @@ public abstract  class SpaimGraphAbtractWriter {
 	public abstract   Connection connect() throws Exception;
 
 	
- 
-	/*ERROR 10/2017:
-	 * 
-=> molecule_id count error
-root@en1:~/KRF/docker_krf_mysql# grep 'MO000002100' ../db/reactome_pid_kegg_pc.sql | grep transpath_molecule |more
-INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `debug`)
- VALUES ('MO000002100', 'm', 'Class I MHC:B2M', 'ComplexImpl|Class I MHC:B2M');
-INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `debug`)
- VALUES ('MO000002100', 'm', 'CO2', 'SmallMoleculeImpl|CO2');
-
-=> getPK() error
-root@en1:~/KRF/docker_krf_mysql# grep 'SmallMoleculeImpl|CO2' ../db/reactome_pid_kegg_pc.sql | grep transpath_molecule |more
-INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `debug`)
- VALUES ('MO000000172', 'm', 'CO2', 'SmallMoleculeImpl|CO2');
-INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `debug`)
- VALUES ('MO000002100', 'm', 'CO2', 'SmallMoleculeImpl|CO2');
-
-	 */
-	
+  	
 	
 	public   void iterateAndComplete(
 			 
@@ -235,12 +217,10 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 			if (be.getClass().isAssignableFrom(PhysicalEntity.class) || be instanceof PhysicalEntity ){
 					 
 				 
-				// PhysicalEntity phe  = (PhysicalEntity) be;
-				 
-				
-				 	String typeOfMolecule ="u";//g (gene) m (m =protein and small molecule)
-				 	//fm: added u (undefined) 
-					 if(be instanceof ProteinImpl){
+		 		
+				 	String typeOfMolecule ="u"; //fm: added u (undefined) 
+			
+				 	if(be instanceof ProteinImpl){
 						 typeOfMolecule ="m";
 
 					 }
@@ -256,7 +236,7 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 					 else if(be instanceof RnaImpl){
 						 typeOfMolecule ="g";
 					 }
-					 //FIXME : check the effect of the following  simplification
+					 //TODO : check the effect of the following  simplification
 					//DBmolecule
 					 //same label and type -> same entity (warning : this is a compression feature) 
 					DBMolecule m =null;
@@ -315,7 +295,6 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 					v.setDbid(reaction_id);// to be used when during  following "edge to sql" step
 					
 					//TODO
-					//FIXME 
 					// reversible (R3)|irreversible (R1,R2) => from DB examples.  safe ?
 					String reversible=null; 
 					if(v.getSpaimCaseFlat().contains("R1")){
@@ -329,6 +308,8 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 				    }else{
 				    	 reversible=REVERSIBLE_VALUE;   // all other not tagged  cases  
 				    }
+					
+					
 					//--> put Rx in all nodes extraced from a pattern 
 					/*
 					 * When at least one of the species-specific reactions was indicated as reversible, the unified generic reaction was then considered as reversible.
@@ -353,15 +334,14 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 						}
 						// activation, inhibition, inhibition-allosteric, inhinition-competitive, inhibition-irreversible,
 						//inhibition-noncompetitive, inhibition-other, inhibition-uncompetitive, activation-nonallosteric, activation-allosteric
-						//TODO
-						//FIXME
+						//TODO 
 						//reversible ???
 						
 						if(ct!=null){
 							 
 							
 								if( ct.startsWith("IRREVERSIBLE")  ){
-									//?????
+									 
 									reversible=IRREVERSIBLE_VALUE;
 								}
 						
@@ -378,7 +358,7 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 								}
 								
 								if(be instanceof TemplateReactionRegulationImpl ) {
-									//FIXME : EFFECT_EXPRESSION ?? shoudl we use controlType here (effect expression +/-) ?
+									//TODO : EFFECT_EXPRESSION ?? shoudl we use controlType here (effect expression +/-) ?
 									if(ct.startsWith("ACTIVATION")){
 										effect="EFFECT_EXPRESSION";
 									}
@@ -404,8 +384,7 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 						if( reversible==null || level==null ||reaction_id==null || effect==null ){
 							doInsertEnt=false;
 						}else{
-						    //INSERT INTO `transpath_reaction` (`reaction_id`, `level`, `reversible`, `effect`, `reaction_description`) VALUES
-						    //('XN000000003', 'mechanistic', 'reversible', 'EFFECT_NOT_DEFINED', 'Grb-2 + Sos <==> Grb-2:Sos');
+						
 							r = new DBReaction(reaction_id, level, reversible, effect, reaction_description);
 							v.setReversible(reversible);// for further generic_signal equilibrium_id generation during edges analysis 
 							r.setDebug(v.getBiopaxType()+"|"+v.getLabel());
@@ -450,9 +429,6 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 				//TODO
 				
 				String role_id=e.getSpaim();
-				// 	EXPRESSION_OF_G000014_FOR_MO000028913 	G000014 	a
-				//XN000216273 	MO000158040 	p
-			    //XN000216273 	MO000088151 	s
 				
 				String molecule_id=null;
 				 String rev =null;
@@ -522,9 +498,7 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 					
 					/*
 					 * 
-					select count(distinct(signal_id)) from	generic_signal_spaim; -> 158554
-					select count(distinct(signal_id)) from	generic_signal;-> 158554
-					
+				 	
 					"When at least one of the species-specific reactions was indicated as reversible, the unified generic reaction was
 					 then considered as reversible. Some molecules could be considered as not limiting
 						and highly generic in many reactions, so they were removed from the reaction sets:
@@ -587,8 +561,6 @@ INSERT INTO `transpath_molecule` (`molecule_id`, `type_of_molecule`, `name`, `de
 			conn.close();
 		}
 	 
-		
-		
 		if(doHub ==true){
 			   writeHubToFile();
 			   writeLoessDataToFile();
