@@ -594,13 +594,20 @@ public class SpaimGraphGenerator {
 
 	private SpaimNode processToSubGraph( Process  c, String cas, String patc) throws Exception {
 		
+		if (c==null) {
+			logger.error("<<<<<processToSubGraph-:null-process>>");
+			return null;
+		}
+		
+		
 		logger.trace("<<<<<processToSubGraph>>");
 		SpaimNode rnode=null;
 		boolean validEntity=false;
 
 		boolean tograph=true;
 		String msg="";
-
+        
+       
 		if (c.getClass().isAssignableFrom(Interaction.class) || c instanceof Interaction ){
 			//BiochemicalReaction|ComplexAssembly|Transport
 			if (c.getClass().isAssignableFrom(Conversion.class) || c instanceof Conversion ){
