@@ -1,3 +1,5 @@
+import logging
+
 import matplotlib
 matplotlib.use('Agg')
 import matplotlib.pyplot as plt
@@ -6,6 +8,10 @@ import graph_tool.all as gt
 import pandas as pd
 import argparse
 
+
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
 def hyperbolicTangent(n):
     return np.tanh(x)
 
