@@ -28,12 +28,14 @@ from pax2graphml import graph_explore
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
  
-def biopax_to_reaction_graph(biopax_file,graphml_file,blackList=None):
+def biopax_to_reaction_graph(biopax_file,graphml_file,black_list=None,control_mode=2):
 
     """Generate a reaction graph with binary interactions as a GRAPHML file from a BIOPAX file. Tte BIOPAX file is filtered, keeping only the regulation part (metabolism and genes). The process use PAXTOOLS, need a lot of memory and can be slow for big BIOPAX files:
 
     :param biopax_file: input BIOPAX file
     :param graphml_file: output GRAPHML reaction file
+    :param black_list: entity black_list (e.g. hubs, h2o...)
+    :param control_mode:  control mecanism model representation, use default (2) for compressed control representation, or 1 for extended with entity duplication
     :return: void
     :rtype: None
   
@@ -41,12 +43,12 @@ def biopax_to_reaction_graph(biopax_file,graphml_file,blackList=None):
 
     cls="dyliss.biopax.app.Pax2GraphML"
 
-    if blackList is not None:
-       blackListOpt=" -b %s" %(blackList)
+    if black_list is not None:
+       black_listOpt=" -b %s" %(black_list)
     else:
-       blackListOpt=""
+       black_listOpt=""
 
-    cmd="%s %s -cp %s %s -i '%s' -o '%s' -t '%s' %s" %(utils.__jvm(),utils.__jvmopt(),utils.__jarpath(),cls,biopax_file,graphml_file,utils.__template(), blackListOpt)
+    cmd="%s %s -cp %s %s -i '%s' -o '%s' -t '%s' -c '%s' %s" %(utils.__jvm(),utils.__jvmopt(),utils.__jarpath(),cls,biopax_file,graphml_file,utils.__template(),control_mode, black_listOpt)
     logger.info("command : %s" %(cmd))
     return utils.__runCmd(cmd)
 
