@@ -519,6 +519,7 @@ def copy_node_properties(g, sourceNode, targetNode):
     for prop in g.vertex_properties.keys():
         g.vp[prop][targetNode]=g.vp[prop][sourceNode]
 
+
  
 def copy_edge_properties(g, source_edge, target_edge):
 
@@ -537,6 +538,101 @@ def copy_edge_properties(g, source_edge, target_edge):
 
 
 
+def populate_shape(g,shapes=None):
+
+  """define the node shapes:
+
+    :param g: a graph
+    :param color: the target property name
+    :param shapes: optional dictionnary of existing values  (dict keys) associated with the new values (dict values) 
+    :return:  count of modified nodes
+ 
+  """ 
+
+  #default shapes
+  map_values={
+   "0":"Ellipse",
+   "1":"Rectangle",
+   "2":"Octagon",
+   "3":"Triangle",
+   "4":"Parallelogram",
+   "5":"Round Rectangle",
+   "6": "Rectangle",
+   "7": "Diamond",
+   "8": "V"
+   }
+
+  if shapes is not None:
+     map_values=shapes
+
+  replace_property_values(g,"shape", map_values)
+
+
+def populate_color(g,colors=None):
+
+  """define the node colors:
+
+    :param g: a graph
+    :param color: the target property name
+    :param colors: optional dictionnary of existing values  (dict keys) assopiated with the new values (dict values) 
+    :return:  count of modified nodes
+ 
+  """ 
+
+
+
+  #default colors
+  map_values={
+   "0":"Red",
+   "1":"FireBrick",
+   "2":"LimeGreen",
+   "3":"LightGreen",
+   "4":"SpringGreen",
+   "5":"SeaGreen",
+   "6":"YellowGreen",
+   "7":"CornflowerBlue",
+   "8":"LightSalmon",
+   "9":"Coral"
+  }
+ 
+  if colors is not None:
+     map_values=colors
+
+ 
+  return replace_property_values(g,"color", map_values)
+
+
+def replace_property_values(g,prop_name, map_values,entity_type="node"):
+
+  """Replace the values of a property by  the specified values:
+
+    :param g: a graph
+    :param prop_name: the target property name
+    :param map_values: dictionnary of existing values  (dict keys) assopiated with the new values (dict values) 
+    :param entity_type:  related entity type, "node" for node, "edge" for edge
+    :return:  count of modified entities
+ 
+  """ 
+  ct=0
+  if entity_type == "node":
+    if prop_name in g.vp.keys():
+      for n in g.vertices():
+        ov=g.vp[prop_name][n]
+        if ov in map_values.keys():
+           g.vp[prop_name][n]=map_values[ov]
+           ct=ct+1  
+  elif entity_type == "edge":
+    if prop_name in g.ep.keys():
+      for e in g.edges():
+        ov=g.ep[prop_name][e]
+        if ov in map_values.keys():
+           g.ep[prop_name][e]=map_values[ov]
+           ct=ct+1
+  return ct
+
+
+
+
 def string_to_list_property(g, string_prop,new_property=None, sep=";", entity="node"):
 
   """Convert a string property to a property contains a list, for each node or edge:
