@@ -293,9 +293,13 @@ def friendly_format_graphml(graphml_file,usetemp=False):
  
 __P2GJAR="biopax2spaimgen.jar"
 __P2GTEMPLATE="graphml.vm"
-__P2GJMEM=" -Xmx48g  -XX:+UseConcMarkSweepGC  "
+__P2GJMEM_XMX="48g"
+__P2GJMEM=" -Xmx"+__P2GJMEM_XMX+"  -XX:+UseConcMarkSweepGC  "
 __P2GJVM="java" 
 
+
+
+
 def __gdirEnv():
    """ return the value of an optional evironment variable for alternate resources directory definition""" 
    p2gjdir=os.getenv("P2GJDIR")
@@ -712,6 +716,17 @@ def __format_graphml_yed(graphml_file,usetemp=False):
 
 
 
+
+def defineXmx(xmx):
+   """ redefine xmx java parameter for lareg BIOPAX file processing""" 
+   global __P2GJMEM_XMX
+   __P2GJMEM_XMX=xmx
+   global __P2GJMEM
+   __P2GJMEM=" -Xmx"+__P2GJMEM_XMX+"  -XX:+UseConcMarkSweepGC  "
+
+
+
+
 if __name__ == "__main__":
      print("no main defined")
 
